@@ -19,10 +19,9 @@ class WebApi(threading.Thread):
     def __init__(self, *args):             # self, imageFile, image-identifier, queue
         threading.Thread.__init__(self)
         self.imageFile = args[0]
-        self.identifier= args[1]
-        self.notifyQue = args[2]
-        self.client    = args[3]
-        self.address   = args[4]
+        self.notifyQue = args[1]
+        self.passToken = args[2]
+        self.address   = args[3]
         
         
         self.fileName   = self.imageFile.split('/')[-1]
@@ -35,18 +34,44 @@ class WebApi(threading.Thread):
 #qForGui format: [device_index, retCode, QRcode, message]
         
     def addTest(self):
-        service = "/ctestlookspot/addtest?"
-        keys = "&testid="+self.cassetteId+ "&place="+self.address[0]+ "&city="+self.address[1]+ "&country="+self.address[2]+"&timestamp="+\
-        str(self.timeStamp)+'000'+"&mode=speed"+\
-        "&localdate="+time.strftime("%d/%m/%Y",time.localtime(self.timeStamp))+\
-        "&localtime="+time.strftime("%H:%M:%S",time.localtime(self.timeStamp))+\
-        "&readerserial="+SERIAL_NO
-        url = baseUrl+service+self.client+keys
-        print("addtest",url)
-        payload  = {}
-        headers  = {}
+        
+        service = "/ctestlookspot/addtest"
+        url  = baseUrl+service
+        payload = json.dumps({
+          "passtoken": self.passToken,
+          "testid": self.cassetteId,
+          "place": self.address[0],
+          "city": self.address[1],
+          "country": self.address[2],
+          "timestamp": str(self.timeStamp)+'000',
+          "mode": "speed",
+          "localdate": time.strftime("%d/%m/%Y",time.localtime(self.timeStamp)),
+          "localtime": time.strftime("%H:%M:%S",time.localtime(self.timeStamp)),
+          "readerserial": SERIAL_NO
+        })
+        headers = {
+          'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz',
+          'Content-Type': 'application/json'
+        }
+        
+        #print(payload)
         response = requests.request("POST", url, headers=headers, data=payload)
         
+        print(response.text)
+        
+        
+#         service = "/ctestlookspot/addtest?"
+#         keys = "&testid="+self.cassetteId+ "&place="+self.address[0]+ "&city="+self.address[1]+ "&country="+self.address[2]+"&timestamp="+\
+#         str(self.timeStamp)+'000'+"&mode=speed"+\
+#         "&localdate="+time.strftime("%d/%m/%Y",time.localtime(self.timeStamp))+\
+#         "&localtime="+time.strftime("%H:%M:%S",time.localtime(self.timeStamp))+\
+#         "&readerserial="+SERIAL_NO
+#         url = baseUrl+service+self.client+keys
+#         #print("addtest",url)
+#         payload  = {}
+#         headers  = {}
+#         response = requests.request("POST", url, headers=headers, data=payload)
+        
         parsing=json.loads(response.text)
         if parsing[CODE] == RESPONSE_SUCCESS:
             return parsing[RSLT][RCID]
@@ -54,22 +79,49 @@ class WebApi(threading.Thread):
         
 
     def uploadImage(self):
-        service = "/testimagelookspot/upload?"
         if self.photoIndex == 0:
             imageIndex=self.photoIndex
         else:
             imageIndex=self.photoIndex-1
-        keys = "&lstestrecordid="+ str(recordId[self.slotNo])+"&lstestid="+self.cassetteId+"&imageindex="+ str(imageIndex)
-        url = baseUrl+service+self.client+keys
-        #url = "https://www.locationnow.com/lnservices/ws/testimagelookspot/upload?client=laipac&signature=laipacws&passtoken=1b9f3867298b394a&lstestrecordid=6118&lstestid=La0000888&imageindex=0"
-        payload={}
+
+        service = "/testimagelookspot/upload"
+        url = baseUrl + service
+        payload={'passtoken': self.passToken,
+        'lstestrecordid': str(recordId[self.slotNo]),
+        'lstestid': self.cassetteId,
+        'imageindex': str(imageIndex)}
         files=[
           ('uploadimage',(self.fileName,open(self.imageFile,'rb'),'image/jpeg'))
         ]
-        headers = {}
-        response = requests.request("POST", url, headers=headers, data=payload, files=files)        
+        headers = {
+          'Authorization': 'Basic bGFpcGFjOmxhaXBhY3dz'
+        }
+        
+        #print(payload)
+        response = requests.request("POST", url, headers=headers, data=payload, files=files)
+        
         print(response.text)
         
+        
+        
+        
+        
+#         service = "/testimagelookspot/upload?"
+#         if self.photoIndex == 0:
+#             imageIndex=self.photoIndex
+#         else:
+#             imageIndex=self.photoIndex-1
+#         keys = "&lstestrecordid="+ str(recordId[self.slotNo])+"&lstestid="+self.cassetteId+"&imageindex="+ str(imageIndex)
+#         url = baseUrl+service+self.client+keys
+#         #url = "https://www.locationnow.com/lnservices/ws/testimagelookspot/upload?client=laipac&signature=laipacws&passtoken=1b9f3867298b394a&lstestrecordid=6118&lstestid=La0000888&imageindex=0"
+#         payload={}
+#         files=[
+#           ('uploadimage',(self.fileName,open(self.imageFile,'rb'),'image/jpeg'))
+#         ]
+#         headers = {}
+#         response = requests.request("POST", url, headers=headers, data=payload, files=files)        
+#         print(response.text)
+        
         parsing=json.loads(response.text)
         if parsing[CODE] == RESPONSE_SUCCESS:                            
             self.notifyQue.put([self.slotNo, int(parsing[RSLT][RCODE]), self.cassetteId, parsing[RSLT][MSSG], recordId[self.slotNo]])
@@ -89,7 +141,7 @@ class WebApi(threading.Thread):
     
 def sendToApi(imageFile, notifyQue, passToken, address): # uploading imagefile name and test result share same queue, file name is string, test result is a list.
     if type(imageFile) ==str:
-        webApi=WebApi(IMG_PATH+imageFile, imageFile.split('.')[0], notifyQue, passToken, address)
+        webApi=WebApi(IMG_PATH+imageFile, notifyQue, passToken, address)
         webApi.start()
     else:
         sendResult=SendResult(imageFile, passToken)
